==> crlfi-0.0.2.tar.gz: crlfi-0.0.2/README.md <==

<div align="center">
  <img src="https://raw.githubusercontent.com/Cappricio-Securities/CVE-2023-29489/main/images/CVE-2023-29489.png" alt="logo">
</div>


## Badges



[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://choosealicense.com/licenses/mit/)
![PyPI - Version](https://img.shields.io/pypi/v/crlfi)
![PyPI - Downloads](https://img.shields.io/pypi/dm/crlfi)
![GitHub all releases](https://img.shields.io/github/downloads/Cappricio-Securities/crlfi/total)
<a href="https://github.com/Cappricio-Securities/crlfi/releases/"><img src="https://img.shields.io/github/release/Cappricio-Securities/crlfi"></a>![Profile_view](https://komarev.com/ghpvc/?username=Cappricio-Securities&label=Profile%20views&color=0e75b6&style=flat)
[![Follow Twitter](https://img.shields.io/twitter/follow/cappricio_sec?style=social)](https://twitter.com/cappricio_sec)
<p align="center">

<p align="center">







## License

[MIT](https://choosealicense.com/licenses/mit/)



## Installation 

1. Install Python3 and pip [Instructions Here](https://www.python.org/downloads/) (If you can't figure this out, you shouldn't really be using this)

   - Install via pip
     - ```bash
          pip install CVE-2023-29489 
        ```
   - Run bellow command to check
     - `CVE-2023-29489 -h`

## Configurations 
2. We integrated with the Telegram API to receive instant notifications for vulnerability detection.
   
   - Telegram Notification
     - ```bash
          CVE-2023-29489 --chatid <YourTelegramChatID>
        ```
   - Open your telegram and search for [`@CappricioSecuritiesTools_bot`](https://web.telegram.org/k/#@CappricioSecuritiesTools_bot) and click start

## Usages 
3. This tool has multiple use cases.
   
   - To Check Single URL
     - ```bash
          CVE-2023-29489 -u http://example.com 
        ```
   - To Check List of URL 
      - ```bash
          CVE-2023-29489 -i urls.txt 
        ```
   - Save output into TXT file
      - ```bash
          CVE-2023-29489 -i urls.txt -o out.txt
        ```
   - Want to Learn about [`CVE-2023-29489`](https://blogs.cappriciosec.com/cve/137/CVE-2023-29489)? Then Type Below command
      - ```bash
          CVE-2023-29489 -b
        ```
     
<p align="center">
  <b>🚨 Disclaimer</b>
  
</p>
<p align="center">
<b>This tool is created for security bug identification and assistance; Cappricio Securities is not liable for any illegal use. 
  Use responsibly within legal and ethical boundaries. 🔐🛡️</b></p>


## Working PoC Video

[![asciicast](https://blogs.cappriciosec.com/uploaders/cve1.png)](https://asciinema.org/a/xB30FPnwpUJiqiyVzY20OutOD)




## Help menu

#### Get all items

```bash
👋 Hey Hacker
                                                                v1.0
  ______   ______    ___  ___  ___  ____    ___ ___  ____ ___ ___ 
 / ___/ | / / __/___|_  |/ _ \|_  ||_  /___|_  / _ \/ / /( _ ) _ \
/ /__ | |/ / _//___/ __// // / __/_/_ <___/ __/\_, /_  _/ _  \_, /
\___/ |___/___/   /____/\___/____/____/  /____/___/ /_/ \___/___/    

                                   Developed By https://cappriciosec.com


CVE-2023-29489 : Bug scanner for WebPentesters and Bugbounty Hunters 

$ CVE-2023-29489 [option]

Usage: CVE-2023-29489 [options]
```


| Argument | Type     | Description                | Examples |
| :-------- | :------- | :------------------------- | :------------------------- |
| `-u` | `--url` | URL to scan | CVE-2023-29489 -u https://target.com |
| `-i` | `--input` | filename Read input from txt  | CVE-2023-29489 -i target.txt | 
| `-o` | `--output` | filename Write output in txt file | CVE-2023-29489 -i target.txt -o output.txt |
| `-c` | `--chatid` | Creating Telegram Notification | CVE-2023-29489 --chatid yourid |
| `-b` | `--blog` | To Read about CVE-2023-29489 Bug | CVE-2023-29489 -b |
| `-h` | `--help` | Help Menu | CVE-2023-29489 -h |



## 🔗 Links
[![Website](https://img.shields.io/badge/my_portfolio-000?style=for-the-badge&logo=ko-fi&logoColor=white)](https://cappriciosec.com/)
[![linkedin](https://img.shields.io/badge/linkedin-0A66C2?style=for-the-badge&logo=linkedin&logoColor=white)](https://www.linkedin.com/in/karthikeyan--v/)
[![twitter](https://img.shields.io/badge/twitter-1DA1F2?style=for-the-badge&logo=twitter&logoColor=white)](https://twitter.com/karthithehacker)



## Author

- [@karthithehacker](https://github.com/karthi-the-hacker/)



## Feedback

If you have any feedback, please reach out to us at contact@karthithehacker.com

==> crlfi-0.0.3.tar.gz: crlfi-0.0.3/README.md <==

<div align="center">
  <img src="https://raw.githubusercontent.com/Cappricio-Securities/crlfi/main/image/CRLFI.png" alt="logo">
</div>


## Badges



[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://choosealicense.com/licenses/mit/)
![PyPI - Version](https://img.shields.io/pypi/v/crlfi)
![PyPI - Downloads](https://img.shields.io/pypi/dm/crlfi)
![GitHub all releases](https://img.shields.io/github/downloads/Cappricio-Securities/crlfi/total)
<a href="https://github.com/Cappricio-Securities/crlfi/releases/"><img src="https://img.shields.io/github/release/Cappricio-Securities/crlfi"></a>![Profile_view](https://komarev.com/ghpvc/?username=Cappricio-Securities&label=Profile%20views&color=0e75b6&style=flat)
[![Follow Twitter](https://img.shields.io/twitter/follow/cappricio_sec?style=social)](https://twitter.com/cappricio_sec)
<p align="center">

<p align="center">







## License

[MIT](https://choosealicense.com/licenses/mit/)



## Installation 

1. Install Python3 and pip [Instructions Here](https://www.python.org/downloads/) (If you can't figure this out, you shouldn't really be using this)

   - Install via pip
     - ```bash
          pip install crlfi
        ```
   - Run bellow command to check
     - `crlfi -h`

## Configurations 
2. We integrated with the Telegram API to receive instant notifications for vulnerability detection.
   
   - Telegram Notification
     - ```bash
          crlfi --chatid <YourTelegramChatID>
        ```
   - Open your telegram and search for [`@CappricioSecuritiesTools_bot`](https://web.telegram.org/k/#@CappricioSecuritiesTools_bot) and click start

## Usages 
3. This tool has multiple use cases.
   
   - To Check Single URL
     - ```bash
          crlfi -u http://example.com 
        ```
   - To Check List of URL 
      - ```bash
          crlfi -i urls.txt 
        ```
   - Save output into TXT file
      - ```bash
          crlfi -i urls.txt -o out.txt
        ```
   - Want to Learn about [`crlfi`](https://blogs.cappriciosec.com/blog/138/Cappricio%20Securities%20Discovers%20CRLF%20Injection%20Vulnerability%20in%20Popular%20Website,%20Responsible%20Disclosure%20Earns%20Bounty)? Then Type Below command
      - ```bash
          crlfi -b
        ```
     
<p align="center">
  <b>🚨 Disclaimer</b>
  
</p>
<p align="center">
<b>This tool is created for security bug identification and assistance; Cappricio Securities is not liable for any illegal use. 
  Use responsibly within legal and ethical boundaries. 🔐🛡️</b></p>


## Working PoC Video

[![asciicast](https://blogs.cappriciosec.com/uploaders/Screenshot%202024-04-23%20at%202.32.40%20PM.png)](https://asciinema.org/a/CZVs5PpxP7cFBvNAeNurt5hxt)




## Help menu

#### Get all items

```bash
👋 Hey Hacker
                                v1.0
   __________  __    __________
  / ____/ __ \/ /   / ____/  _/
 / /   / /_/ / /   / /_   / /
/ /___/ _, _/ /___/ __/ _/ /
\____/_/ /_/_____/_/   /___/

                                Developed By https://cappriciosec.com


crlfi : Bug scanner for WebPentesters and Bugbounty Hunters 

$ crlfi [option]

Usage: crlfi [options]
```


| Argument | Type     | Description                | Examples |
| :-------- | :------- | :------------------------- | :------------------------- |
| `-u` | `--url` | URL to scan | crlfi -u https://target.com |
| `-i` | `--input` | filename Read input from txt  | crlfi -i target.txt | 
| `-o` | `--output` | filename Write output in txt file | crlfi -i target.txt -o output.txt |
| `-c` | `--chatid` | Creating Telegram Notification | crlfi --chatid yourid |
| `-b` | `--blog` | To Read about crlfi Bug | crlfi -b |
| `-h` | `--help` | Help Menu | crlfi -h |



## 🔗 Links
[![Website](https://img.shields.io/badge/my_portfolio-000?style=for-the-badge&logo=ko-fi&logoColor=white)](https://cappriciosec.com/)
[![linkedin](https://img.shields.io/badge/linkedin-0A66C2?style=for-the-badge&logo=linkedin&logoColor=white)](https://www.linkedin.com/in/karthikeyan--v/)
[![twitter](https://img.shields.io/badge/twitter-1DA1F2?style=for-the-badge&logo=twitter&logoColor=white)](https://twitter.com/karthithehacker)



## Author

- [@cappriciosec](https://github.com/cappricio-securities/)



## Feedback

If you have any feedback, please reach out to us at contact@cappriciosec.com
